==> zio-aws-location_2.12-5.17.130.6-sources.jar: zio/aws/location/model/SearchForTextResult.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.location.model.primitives.{
  SearchForTextResultRelevanceDouble,
  SearchForTextResultDistanceDouble
}
import scala.jdk.CollectionConverters._
final case class SearchForTextResult(
    distance: Option[SearchForTextResultDistanceDouble] = None,
    place: zio.aws.location.model.Place,
    relevance: Option[SearchForTextResultRelevanceDouble] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.SearchForTextResult = {
    import SearchForTextResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.SearchForTextResult
      .builder()
      .optionallyWith(
        distance.map(value =>
          SearchForTextResultDistanceDouble.unwrap(value): java.lang.Double
        )
      )(_.distance)
      .place(place.buildAwsValue())
      .optionallyWith(
        relevance.map(value =>
          SearchForTextResultRelevanceDouble.unwrap(value): java.lang.Double
        )
      )(_.relevance)
      .build()
  }
  def asReadOnly: zio.aws.location.model.SearchForTextResult.ReadOnly =
    zio.aws.location.model.SearchForTextResult.wrap(buildAwsValue())
}
object SearchForTextResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.SearchForTextResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.SearchForTextResult =
      zio.aws.location.model.SearchForTextResult(
        distance.map(value => value),
        place.asEditable,
        relevance.map(value => value)
      )
    def distance: Option[SearchForTextResultDistanceDouble]
    def place: zio.aws.location.model.Place.ReadOnly
    def relevance: Option[SearchForTextResultRelevanceDouble]
    def getDistance: ZIO[Any, AwsError, SearchForTextResultDistanceDouble] =
      AwsError.unwrapOptionField("distance", distance)
    def getPlace: ZIO[Any, Nothing, zio.aws.location.model.Place.ReadOnly] =
      ZIO.succeed(place)
    def getRelevance: ZIO[Any, AwsError, SearchForTextResultRelevanceDouble] =
      AwsError.unwrapOptionField("relevance", relevance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.SearchForTextResult
  ) extends zio.aws.location.model.SearchForTextResult.ReadOnly {
    override val distance: Option[SearchForTextResultDistanceDouble] = scala
      .Option(impl.distance())
      .map(value =>
        zio.aws.location.model.primitives
          .SearchForTextResultDistanceDouble(value)
      )
    override val place: zio.aws.location.model.Place.ReadOnly =
      zio.aws.location.model.Place.wrap(impl.place())
    override val relevance: Option[SearchForTextResultRelevanceDouble] = scala
      .Option(impl.relevance())
      .map(value =>
        zio.aws.location.model.primitives
          .SearchForTextResultRelevanceDouble(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.SearchForTextResult
  ): zio.aws.location.model.SearchForTextResult.ReadOnly = new Wrapper(impl)
}

==> zio-aws-location_2.12-5.17.201.2-sources.jar: zio/aws/location/model/SearchForTextResult.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.location.model.primitives.{
  SearchForTextResultRelevanceDouble,
  SearchForTextResultDistanceDouble
}
import scala.jdk.CollectionConverters._
final case class SearchForTextResult(
    distance: Optional[SearchForTextResultDistanceDouble] = Optional.Absent,
    place: zio.aws.location.model.Place,
    relevance: Optional[SearchForTextResultRelevanceDouble] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.SearchForTextResult = {
    import SearchForTextResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.SearchForTextResult
      .builder()
      .optionallyWith(
        distance.map(value =>
          SearchForTextResultDistanceDouble.unwrap(value): java.lang.Double
        )
      )(_.distance)
      .place(place.buildAwsValue())
      .optionallyWith(
        relevance.map(value =>
          SearchForTextResultRelevanceDouble.unwrap(value): java.lang.Double
        )
      )(_.relevance)
      .build()
  }
  def asReadOnly: zio.aws.location.model.SearchForTextResult.ReadOnly =
    zio.aws.location.model.SearchForTextResult.wrap(buildAwsValue())
}
object SearchForTextResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.SearchForTextResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.SearchForTextResult =
      zio.aws.location.model.SearchForTextResult(
        distance.map(value => value),
        place.asEditable,
        relevance.map(value => value)
      )
    def distance: Optional[SearchForTextResultDistanceDouble]
    def place: zio.aws.location.model.Place.ReadOnly
    def relevance: Optional[SearchForTextResultRelevanceDouble]
    def getDistance: ZIO[Any, AwsError, SearchForTextResultDistanceDouble] =
      AwsError.unwrapOptionField("distance", distance)
    def getPlace: ZIO[Any, Nothing, zio.aws.location.model.Place.ReadOnly] =
      ZIO.succeed(place)
    def getRelevance: ZIO[Any, AwsError, SearchForTextResultRelevanceDouble] =
      AwsError.unwrapOptionField("relevance", relevance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.SearchForTextResult
  ) extends zio.aws.location.model.SearchForTextResult.ReadOnly {
    override val distance: Optional[SearchForTextResultDistanceDouble] =
      zio.aws.core.internal
        .optionalFromNullable(impl.distance())
        .map(value =>
          zio.aws.location.model.primitives
            .SearchForTextResultDistanceDouble(value)
        )
    override val place: zio.aws.location.model.Place.ReadOnly =
      zio.aws.location.model.Place.wrap(impl.place())
    override val relevance: Optional[SearchForTextResultRelevanceDouble] =
      zio.aws.core.internal
        .optionalFromNullable(impl.relevance())
        .map(value =>
          zio.aws.location.model.primitives
            .SearchForTextResultRelevanceDouble(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.SearchForTextResult
  ): zio.aws.location.model.SearchForTextResult.ReadOnly = new Wrapper(impl)
}
